pub unsafe extern "C" fn aeron_archive_persistent_subscription_context_close(
context: *mut aeron_archive_persistent_subscription_context_t,
) -> c_intExpand description
Close and dispose of all resources held by the persistent subscription context.
If the context created its own Aeron client (i.e. none was set via aeron_archive_persistent_subscription_context_set_aeron), that client will be closed here.
@param context to close. @return 0 on success, -1 on error.