aeron_archive_persistent_subscription_context_set_aeron

Function aeron_archive_persistent_subscription_context_set_aeron 

pub unsafe extern "C" fn aeron_archive_persistent_subscription_context_set_aeron(
    context: *mut aeron_archive_persistent_subscription_context_t,
    aeron: *mut aeron_t,
) -> c_int
Set the Aeron client that will be used by the persistent subscription.

If not set, the persistent subscription will create and own its own Aeron client when aeron_archive_persistent_subscription_create is called. In that case, the client will be closed when the context is closed via aeron_archive_persistent_subscription_context_close.

@param context to configure. @param aeron the Aeron client to use. @return 0 on success, -1 on error.