pub unsafe extern "C" fn aeron_archive_persistent_subscription_context_set_aeron_directory_name(
context: *mut aeron_archive_persistent_subscription_context_t,
aeron_directory_name: *const c_char,
) -> c_intExpand description
Set the Aeron directory name to use when the persistent subscription creates its own Aeron client. Has no effect if an Aeron client is set via aeron_archive_persistent_subscription_context_set_aeron.
The directory name is copied into the context. The caller retains ownership of the supplied string.
@param context to configure. @param aeron_directory_name the Aeron directory name. @return 0 on success, -1 on error.