aeron_archive_persistent_subscription_context_set_join_difference_counter

Function aeron_archive_persistent_subscription_context_set_join_difference_counter 

pub unsafe extern "C" fn aeron_archive_persistent_subscription_context_set_join_difference_counter(
    context: *mut aeron_archive_persistent_subscription_context_t,
    counter: *mut aeron_counter_t,
) -> c_int
Set the counter for tracking the join difference of the persistent subscription. The join difference is the difference between the live position and the replay position when transitioning. When not live, the value is INT64_MIN.

@param context to configure. @param counter the join difference counter. @return 0 on success, -1 on error.