aeron_archive_persistent_subscription_create

Function aeron_archive_persistent_subscription_create 

pub unsafe extern "C" fn aeron_archive_persistent_subscription_create(
    persistent_subscription: *mut *mut aeron_archive_persistent_subscription_t,
    context: *mut aeron_archive_persistent_subscription_context_t,
) -> c_int
Create a persistent subscription.

If creating a subscription succeeds, then the subscription will own the context. And closing the subscription, will close the context.

If no Aeron client is set on the context, one will be created and owned by the context, and will be closed when the context is closed via aeron_archive_persistent_subscription_context_close.

@param persistent_subscription to set if completed successfully. @param context with the configuration of a persistent subscription to be created. @return 0 on success, -1 on error.