aeron_archive_persistent_subscription_has_failed

Function aeron_archive_persistent_subscription_has_failed 

pub unsafe extern "C" fn aeron_archive_persistent_subscription_has_failed(
    persistent_subscription: *mut aeron_archive_persistent_subscription_t,
) -> bool
Indicates if the persistent subscription has failed.

The listener will be notified of any terminal errors that can cause the persistent subscription to fail.

@param persistent_subscription to check. @return true if failed, false otherwise. @see aeron_archive_persistent_subscription_context_set_listener