aeron_archive_persistent_subscription_poll

Function aeron_archive_persistent_subscription_poll 

pub unsafe extern "C" fn aeron_archive_persistent_subscription_poll(
    persistent_subscription: *mut aeron_archive_persistent_subscription_t,
    handler: aeron_fragment_handler_t,
    clientd: *mut c_void,
    fragment_limit: usize,
) -> c_int
Poll a persistent subscription for available messages.

Delivers assembled messages to the handler, so the handler shouldn't be a fragment assembler.

@param persistent_subscription to poll. @param handler for handling read messages. @param clientd to pass to the handler. @param fragment_limit maximum number of message fragments to read when polling. @return positive number if fragments have been read or the persistent subscription has done other work, 0 if no fragments have been read and no work has been done, negative on error.