aeron_open_file_append

Function aeron_open_file_append 

pub unsafe extern "C" fn aeron_open_file_append(
    path: *const c_char,
) -> *mut c_void
Opens or creates a new file in append mode. Will use 0644 permissions on Linux/Mac and default on Windows.

@param path to the location on the file system. @return A FILE* pointer as a void* to reduce type dependencies. Returns null on failure.