aeron_temp_dir

Function aeron_temp_dir 

pub unsafe extern "C" fn aeron_temp_dir(
    dir_template: *const c_char,
) -> *const c_char
Returns a new temporary directory, allocates the string which needs to be freed by the user.

@param dir_template to be used to create the temporary directory. @return the new temporary path.