pub unsafe extern "C" fn aeron_archive_persistent_subscription_failure_reason(
persistent_subscription: *mut aeron_archive_persistent_subscription_t,
out_errcode: *mut c_int,
out_message: *mut *const c_char,
) -> boolExpand description
Get the terminal error that caused the persistent subscription to fail. Only meaningful when aeron_archive_persistent_subscription_has_failed returns true.
@param persistent_subscription to query. @param out_errcode optional pointer to receive the error code, may be NULL. @param out_message optional pointer to receive the error message, may be NULL. @return true if in the failed state, false otherwise. @see aeron_archive_persistent_subscription_has_failed